MODULE diagflux_mod
  USE icosa
  IMPLICIT NONE
  SAVE
  
  TYPE(t_field),POINTER :: f_qfluxt(:), f_qfluxt_i(:) ! time-integrated flux of scalars and its reconstruction at cell centers
  
  LOGICAL :: diagflux_on
  !$OMP THREADPRIVATE(diagflux_on)

CONTAINS

  SUBROUTINE init_diagflux
    USE getin_mod
    diagflux_on = .FALSE.
    CALL getin("diagflux", diagflux_on)
    IF(diagflux_on) THEN
       CALL allocate_field(f_qfluxt,  field_u,type_real,llm,nqtot, name="qfluxt")
       CALL allocate_field(f_qfluxt_i,  field_t,type_real,llm,nqtot, name="qfluxt_i")
       CALL zero_qfluxt
    ELSE
       CALL allocate_field(f_qfluxt,  field_u,type_real,llm,0, name="qfluxt")
       CALL allocate_field(f_qfluxt_i,  field_t,type_real,llm,0, name="qfluxt_i")
    END IF
  END SUBROUTINE init_diagflux

  SUBROUTINE zero_qfluxt
    USE mpipara
    USE omp_para
    INTEGER :: ind
    REAL(rstd), POINTER :: qfluxt(:,:,:)
    DO ind=1,ndomain
       IF (.NOT. assigned_domain(ind)) CYCLE
       CALL swap_dimensions(ind)
       qfluxt=f_qfluxt(ind)
       qfluxt(:,ll_begin:ll_end,:)=0.
    END DO
  END SUBROUTINE zero_qfluxt
  
END MODULE diagflux_mod
